@@ -84,7 +84,7 @@ class ViewContainer(Gtk.Stack):
             GObject.TYPE_BOOLEAN,
             GObject.TYPE_INT,
             GObject.TYPE_STRING,
-            GObject.TYPE_BOOLEAN,
+            GObject.TYPE_INT,
             GObject.TYPE_BOOLEAN,
             GObject.TYPE_INT
         )
@@ -355,16 +355,21 @@ class Albums(ViewContainer):
         except TypeError:
             return
         title = self.model.get_value(_iter, 2)
-        artist = self.model.get_value(_iter, 3)
+        self._artist = self.model.get_value(_iter, 3)
         item = self.model.get_value(_iter, 5)
-        self._albumWidget.update(artist, title, item,
+        self._albumWidget.update(self._artist, title, item,
                                  self.header_bar, self.selection_toolbar)
         self.header_bar.set_state(ToolbarState.CHILD_VIEW)
-        escaped_title = albumArtCache.get_media_title(item)
-        self.header_bar.header_bar.set_title(escaped_title)
-        self.header_bar.header_bar.sub_title = artist
+        self._escaped_title = albumArtCache.get_media_title(item)
+        self.header_bar.header_bar.set_title(self._escaped_title)
+        self.header_bar.header_bar.sub_title = self._artist
         self.set_visible_child(self._albumWidget)
 
+    @log
+    def update_title(self):
+        self.header_bar.header_bar.set_title(self._escaped_title)
+        self.header_bar.header_bar.sub_title = self._artist
+
     @log
     def populate(self):
         if grilo.tracker:
@@ -850,7 +855,7 @@ class Playlist(ViewContainer):
             GObject.TYPE_BOOLEAN,
             GObject.TYPE_INT,
             GObject.TYPE_STRING,
-            GObject.TYPE_BOOLEAN,
+            GObject.TYPE_INT,
             GObject.TYPE_BOOLEAN,
             GObject.TYPE_INT
         )
@@ -1308,6 +1313,7 @@ class EmptySearch(ViewContainer):
     def __init__(self, window, player):
         ViewContainer.__init__(self, 'emptysearch', None, window, Gd.MainViewType.LIST)
         self._artistAlbumsWidget = None
+        self._albumWidget = None
         self.player = player
 
         builder = Gtk.Builder()
@@ -1325,6 +1331,9 @@ class EmptySearch(ViewContainer):
         if self.get_visible_child() == self._artistAlbumsWidget:
             self._artistAlbumsWidget.destroy()
             self._artistAlbumsWidget = None
+        elif self.get_visible_child() == self._grid:
+            self.window.views[0].set_visible_child(self.window.views[0]._grid)
+            self.window.toolbar.set_state(ToolbarState.CHILD_VIEW)
         self.set_visible_child(self._grid)
 
 
@@ -1382,8 +1391,12 @@ class Search(ViewContainer):
         if self.get_visible_child() == self._artistAlbumsWidget:
             self._artistAlbumsWidget.destroy()
             self._artistAlbumsWidget = None
+        elif self.get_visible_child() == self._grid:
+            self.window.views[0].set_visible_child(self.window.views[0]._grid)
+            self.window.toolbar.set_state(ToolbarState.CHILD_VIEW)
         self.set_visible_child(self._grid)
 
+
     @log
     def _on_item_activated(self, widget, id, path):
         if self.star_handler.star_renderer_click:
@@ -1516,7 +1529,7 @@ class Search(ViewContainer):
                 self.head_iters[group], -1,
                 [0, 2, 3, 4, 5, 9, 11],
                 [str(item.get_id()), title, artist,
-                 self._loadingIcon, item, False, category])
+                 self._loadingIcon, item, 2, category])
             self.cache.lookup(item, self._iconWidth, self._iconHeight, self._on_lookup_ready,
                               _iter, artist, title)
         elif category == 'song':
@@ -1524,14 +1537,14 @@ class Search(ViewContainer):
                 self.head_iters[group], -1,
                 [0, 2, 3, 4, 5, 9, 11],
                 [str(item.get_id()), title, artist,
-                 self._noAlbumArtIcon, item, bool(item.get_lyrics()), category])
+                 self._noAlbumArtIcon, item, 2 if source.get_id() != 'grl-tracker-source' else bool(item.get_lyrics()), category])
         else:
             if not artist.casefold() in self._artists:
                 _iter = self.model.insert_with_values(
                     self.head_iters[group], -1,
                     [0, 2, 4, 5, 9, 11],
                     [str(item.get_id()), artist,
-                     self._loadingIcon, item, False, category])
+                     self._loadingIcon, item, 2, category])
                 self.cache.lookup(item, self._iconWidth, self._iconHeight, self._on_lookup_ready,
                                   _iter, artist, title)
                 self._artists[artist.casefold()] = {'iter': _iter, 'albums': []}
@@ -1559,7 +1572,7 @@ class Search(ViewContainer):
                                  self._on_list_widget_title_render, None)
         cols[0].add_attribute(title_renderer, 'text', 2)
 
-        self.star_handler._add_star_renderers(list_widget, cols, hidden=True)
+        self.star_handler._add_star_renderers(list_widget, cols, hidden=False)
 
         cells = cols[0].get_cells()
         cols[0].reorder(cells[0], -1)
@@ -1711,7 +1724,7 @@ class Search(ViewContainer):
             GObject.TYPE_BOOLEAN,
             GObject.TYPE_INT,
             GObject.TYPE_STRING,
-            GObject.TYPE_BOOLEAN,
+            GObject.TYPE_INT,
             GObject.TYPE_BOOLEAN,
             GObject.TYPE_STRING,    # type
             GObject.TYPE_INT
@@ -1726,10 +1739,10 @@ class Search(ViewContainer):
         if search_term == "":
             return
 
-        albums_iter = self.model.insert_with_values(None, -1, [2], [_("Albums")])
-        artists_iter = self.model.insert_with_values(None, -1, [2], [_("Artists")])
-        songs_iter = self.model.insert_with_values(None, -1, [2], [_("Songs")])
-        playlists_iter = self.model.insert_with_values(None, -1, [2], [_("Playlists")])
+        albums_iter = self.model.insert_with_values(None, -1, [2, 9], [_("Albums"), 2])
+        artists_iter = self.model.insert_with_values(None, -1, [2, 9], [_("Artists"), 2])
+        songs_iter = self.model.insert_with_values(None, -1, [2, 9], [_("Songs"), 2])
+        playlists_iter = self.model.insert_with_values(None, -1, [2, 9], [_("Playlists"), 2])
 
         self.head_iters = [albums_iter, artists_iter, songs_iter, playlists_iter]
         self.songs_model = self.model.filter_new(self.model.get_path(songs_iter))
